@@ -43,6 +43,7 @@
 
 ;; Shutup bytecompiler for emacs-24*
 (defvar package-menu-async) ; Only available on emacs-25.
+(declare-function async-byte-recompile-directory "ext:async-bytecomp.el")
 
 (defun helm-el-package--init ()
   (let (package-menu-async)
@@ -104,26 +105,20 @@
 
 (defun helm-el-package-install-1 (pkg-list)
   (cl-loop with mkd = pkg-list
-        for p in mkd
-        for id = (get-text-property 0 'tabulated-list-id p)
-        do (package-install
-            (if (fboundp 'package-desc-name) id (car id)))
-        collect (if (fboundp 'package-desc-full-name) id (car id))
-        into installed-list
-        finally do (progn
-                     (when (boundp 'package-selected-packages)
-                       (customize-save-variable
-                        'package-selected-packages
-                        (append (mapcar 'package-desc-name installed-list)
-                                package-selected-packages)))
-                     (if (fboundp 'package-desc-full-name)
-                         (message (format "%d packages installed:\n(%s)"
-                                          (length installed-list)
-                                          (mapconcat #'package-desc-full-name
-                                                     installed-list ", ")))
-                         (message (format "%d packages installed:\n(%s)"
-                                          (length installed-list)
-                                          (mapconcat 'symbol-name installed-list ", ")))))))
+           for p in mkd
+           for id = (get-text-property 0 'tabulated-list-id p)
+           do (package-install
+               (if (fboundp 'package-desc-name) id (car id)))
+           collect (if (fboundp 'package-desc-full-name) id (car id))
+           into installed-list
+           finally do (if (fboundp 'package-desc-full-name)
+                          (message (format "%d packages installed:\n(%s)"
+                                           (length installed-list)
+                                           (mapconcat #'package-desc-full-name
+                                                      installed-list ", ")))
+                          (message (format "%d packages installed:\n(%s)"
+                                           (length installed-list)
+                                           (mapconcat 'symbol-name installed-list ", "))))))
 
 (defun helm-el-package-install (_candidate)
   (helm-el-package-install-1 (helm-marked-candidates)))
@@ -212,7 +207,10 @@
                   (ignore))
                  ((equal pkg-desc upgrade)
                   ;;Install.
-                  (package-install pkg-desc))
+                  (with-no-warnings
+                    (if (boundp 'package-selected-packages)
+                        (package-install pkg-desc t)
+                        (package-install pkg-desc))))
                  (t
                   ;; Delete.
                   (if (boundp 'package-selected-packages)
@@ -351,12 +349,23 @@
                     (and (package-built-in-p pkg-name)
                          (assq pkg-name package-alist))))
            (append acts '(("Reinstall package(s)" . helm-el-package-reinstall)
+                          ("Recompile package(s)" . helm-el-package-recompile)
                           ("Uninstall package(s)" . helm-el-package-uninstall))))
           (t (append acts '(("Install packages(s)" . helm-el-package-install)))))))
 
 (defun helm-el-package--update ()
   (setq helm-el-package--initialized-p nil))
 
+(defun helm-el-package-recompile (_pkg)
+  (cl-loop for p in (helm-marked-candidates)
+           for pkg-desc = (get-text-property 0 'tabulated-list-id p)
+           for name = (package-desc-name pkg-desc) 
+           for dir = (package-desc-dir pkg-desc)
+           do (if (fboundp 'async-byte-recompile-directory)
+                  (async-byte-recompile-directory dir)
+                  (when (y-or-n-p (format "Really recompile `%s' while already loaded ?" name))
+                    (byte-recompile-directory dir 0 t)))))
+
 (defun helm-el-package-reinstall (_pkg)
   (cl-loop for p in (helm-marked-candidates)
            for pkg-desc = (get-text-property 0 'tabulated-list-id p)
@@ -374,7 +383,7 @@
                     ;; packages already installed, the name (as symbol)
                     ;; fails with such packages.
                     (package-install
-                     (cadr (assq name package-archive-contents))))
+                     (cadr (assq name package-archive-contents)) t))
                   (package-delete pkg-desc)
                   (package-install name))))
 
