@@ -76,6 +76,18 @@ much more convenient to use a simple boolean value here."
 (defvar helm-suspend-update-flag nil)
 (defvar helm-action-buffer "*helm action*"
   "Buffer showing actions.")
+
+
+;;; Compatibility
+;;
+(defun helm-add-face-text-properties (beg end face &optional append object)
+  "Add the face property to the text from START to END.
+It is a compatibility function which behave exactly like
+`add-face-text-property' if available otherwise like `add-text-properties'.
+When only `add-text-properties' is available APPEND is ignored."
+  (if (fboundp 'add-face-text-property)
+      (add-face-text-property beg end face append object)
+      (add-text-properties beg end `(face ,face) object)))
 
 ;;; Macros helper.
 ;;
@@ -333,6 +345,17 @@ Default is `eq'."
                                              (string-match-p re i)))))
            collect i))
 
+(defun helm-boring-directory-p (directory black-list)
+  "Check if one regexp in BLACK-LIST match DIRECTORY."
+  (helm-awhile (helm-basedir (directory-file-name
+                              (expand-file-name directory)))
+    (when (string= it "/") (cl-return nil))
+    (when (cl-loop for r in black-list
+                   thereis (string-match-p
+                            r (directory-file-name directory)))
+      (cl-return t))
+    (setq directory it)))
+
 (defun helm-shadow-entries (seq regexp-list)
   "Put shadow property on entries in SEQ matching a regexp in REGEXP-LIST."
   (let ((face 'italic))
