@@ -242,9 +242,9 @@ If COLLECTION is an `obarray', a TEST should be needed. See `obarray'."
                                             (helm-basedir helm-pattern)) f)))
                  ((functionp collection)
                   (funcall collection input test t))
-                 ((and alistp test)
-                  (cl-loop for i in collection when (funcall test i) collect i))
-                 (alistp collection)
+                 ((and alistp (null test)) collection)
+                 ;; Next test ensure circular objects are removed
+                 ;; with `all-completions' (Issue #1530).
                  (t (all-completions input collection test)))))
       (if sort-fn (sort cands sort-fn) cands))))
 
@@ -273,6 +273,13 @@ If COLLECTION is an `obarray', a TEST should be needed. See `obarray'."
       (when (string= (get-text-property 0 'display it) "[?]")
         (helm-next-line))))
 
+(defun helm-cr-default (default cands)
+  (cond ((and (stringp default) (not (string= default "")))
+         (delq nil (cons default (delete default cands))))
+        ((consp default)
+         (append default cands))
+        (t cands)))
+
 ;;;###autoload
 (cl-defun helm-comp-read (prompt collection
                           &key
@@ -419,43 +426,33 @@ that use `helm-comp-read' See `helm-M-x' for example."
             (replace-regexp-in-string "helm-maybe-exit-minibuffer"
                                       "helm-confirm-and-exit-minibuffer"
                                       helm-read-file-name-mode-line-string))
-           (get-candidates (lambda ()
-                             (let ((cands (helm-comp-read-get-candidates
-                                           collection test sort alistp)))
-                               (setq helm-cr-unknown-pattern-flag nil)
-                               (unless (or (eq must-match t)
-                                           (string= helm-pattern "")
-                                           (assoc helm-pattern cands)
-                                           (assoc (intern helm-pattern) cands)
-                                           (member helm-pattern cands)
-                                           (member (downcase helm-pattern) cands)
-                                           (member (upcase helm-pattern) cands))
-                                 (setq cands (append (list
-                                                      ;; Unquote helm-pattern
-                                                      ;; when it is added
-                                                      ;; as candidate.
-                                                      (replace-regexp-in-string
-                                                       "\\s\\" "" helm-pattern))
-                                                     cands))
-                                 (setq helm-cr-unknown-pattern-flag t))
-                               ;; When DEFAULT is initially a list, candidates
-                               ;; come already computed with DEFAULT list appended,
-                               ;; and DEFAULT is set to the car of this list.
-                               (if (and default (not (string= default "")))
-                                   (delq nil (cons default (delete default cands)))
-                                 cands))))
-           (history-get-candidates (lambda ()
-                                     (let ((all (helm-comp-read-get-candidates
-                                                 history test nil alistp)))
-                                       (when all
-                                         (delete
-                                          ""
-                                          (helm-fast-remove-dups
-                                           (if (and default (not (string= default "")))
-                                               (delq nil (cons default
-                                                               (delete default all)))
-                                             all)
-                                           :test 'equal))))))
+           (get-candidates
+            (lambda ()
+              (let ((cands (helm-comp-read-get-candidates
+                            collection test sort alistp)))
+                (setq helm-cr-unknown-pattern-flag nil)
+                (unless (or (eq must-match t)
+                            (string= helm-pattern "")
+                            (assoc helm-pattern cands)
+                            (assoc (intern helm-pattern) cands)
+                            (member helm-pattern cands)
+                            (member (downcase helm-pattern) cands)
+                            (member (upcase helm-pattern) cands))
+                  (setq cands (append (list
+                                       ;; Unquote helm-pattern
+                                       ;; when it is added
+                                       ;; as candidate.
+                                       (replace-regexp-in-string
+                                        "\\s\\" "" helm-pattern))
+                                      cands))
+                  (setq helm-cr-unknown-pattern-flag t))
+                (helm-cr-default default cands))))
+           (history-get-candidates
+            (lambda ()
+              (let ((cands (helm-comp-read-get-candidates
+                            history test nil alistp)))
+                (when cands
+                  (delete "" (helm-cr-default default cands))))))
            (src-hist (helm-build-sync-source (format "%s History" name)
                          :candidates history-get-candidates
                          :fuzzy-match fuzzy
@@ -528,19 +525,7 @@ that use `helm-comp-read' See `helm-M-x' for example."
                (setcar history result))
               (t ; Possibly a symbol with a nil value.
                (set history (list result)))))
-      (or
-       result
-       (when (and (eq helm-exit-status 0)
-                  (eq must-match 'confirm))
-         ;; Return empty string only if it is the DEFAULT
-         ;; value and helm-pattern is empty.
-         ;; otherwise return helm-pattern
-         (if (and (string= helm-pattern "") default)
-             default (identity helm-pattern)))
-       (unless (or (eq helm-exit-status 1)
-                   must-match)  ; FIXME this should not be needed now.
-         default)
-       (helm-mode--keyboard-quit)))))
+      (or result (helm-mode--keyboard-quit)))))
 
 ;; Generic completing-read
 ;;
@@ -613,18 +598,6 @@ It should be used when candidate list don't need to rebuild dynamically."
                                    (`(,l . ,_ll) l))
                            (if minibuffer-completing-file-name it
                                (regexp-quote it)))))
-    (when (and default (listp default))
-      ;; When DEFAULT is a list move the list on head of COLLECTION
-      ;; and set it to its car. #bugfix `grep-read-files'.
-      (setq collection
-            ;; COLLECTION is maybe a function or a table.
-            (append default
-                    (helm-comp-read-get-candidates
-                     collection test nil (listp collection))))
-      ;; Ensure `all-completions' will not be used
-      ;; a second time to recompute COLLECTION [1].
-      (setq alistp t)
-      (setq default (car default)))
     (helm-comp-read
      prompt collection
      :test test
@@ -632,9 +605,10 @@ It should be used when candidate list don't need to rebuild dynamically."
      :reverse-history helm-mode-reverse-history
      :input-history history
      :must-match require-match
-     :alistp alistp ; Ensure `all-completions' is used when non-nil [1].
+     :alistp alistp
      :name name
-     :requires-pattern (if (and (string= default "")
+     :requires-pattern (if (and (stringp default)
+                                (string= default "")
                                 (or (eq require-match 'confirm)
                                     (eq require-match
                                         'confirm-after-completion)))
@@ -923,10 +897,6 @@ Keys description:
            ((and result (listp result))
             (mapcar #'expand-file-name result))
            (t result))
-     (when (and (not (string= helm-pattern ""))
-                (eq helm-exit-status 0)
-                (eq must-match 'confirm))
-       (identity helm-pattern))
      (helm-mode--keyboard-quit))))
 
 (defun helm-mode--default-filename (fname dir initial)
@@ -1076,7 +1046,8 @@ Can be used as value for `completion-in-region-function'."
                                 (setcdr last-data nil))
                             0))
                (init-space-suffix (unless (or helm-completion-in-region-fuzzy-match
-                                              (string-suffix-p " " input))
+                                              (string-suffix-p " " input)
+                                              (string= input ""))
                                     " "))
                (file-comp-p (or (eq (completion-metadata-get metadata 'category) 'file)
                                 (helm-mode--in-file-completion-p)
@@ -1115,8 +1086,7 @@ Can be used as value for `completion-in-region-function'."
                           (cond ((and file-comp-p
                                       (not (string-match "/\\'" input)))
                                  (concat (helm-basename input)
-                                         (unless (string= input "")
-                                           init-space-suffix)))
+                                         init-space-suffix))
                                 ((string-match "/\\'" input) nil)
                                 ((or (null require-match)
                                      (stringp require-match))
